<?php

class Bootstrap
{
    /**
     * Static main method: used to run the bootstrapping routine.
     */
    public static function main()
    {
        // Create an instance of the bootstrap class, and call methods.
        $bootstrap = new self();
        $bootstrap->_setup();
        $bootstrap->_setupRegistryItems();
        $bootstrap->_setupRoutes();
        $bootstrap->_dispatch();
    }
    
    /**
     * Configure the front controller and other items needed for the application.
     */
    protected function _setup()
    {        
        $this->_frontController = Zend_Controller_Front::getInstance();
        $this->_frontController->returnResponse(true);
        $this->_frontController->throwExceptions(true);
        
        $this->_frontController->setControllerDirectory(
            array(
                'default' => '../application/controllers'
            )
        );
        
        Zend_Layout::startMvc(
            array(
                'layoutPath' => '../application/views/layouts',
                'layout' => 'common'
            )
        );
        
        // View and view helpers
        $view =  Zend_Layout::getMvcInstance()->getView();
        $view->setEncoding('UTF-8');
    }
    
    /**
     * Set up items in the registry used globally throughout the application.
     */
    protected function _setupRegistryItems()
    {
        Zend_Registry::set('pageDatabase', new DynamicPage_Database());
    }
    
    protected function _setupRoutes()
    {
        $router = $this->_frontController->getRouter();
        
        $pageDatabase = Zend_Registry::get('pageDatabase');
        $pageRouteData = $pageDatabase->buildRouteData();
        
        // Loop over the route data and build the actual routes.
        foreach ($pageRouteData as $pageRouteItem) {
            $router->addRoute(
                'dynamic-page-' . $pageRouteItem[0],
                new Zend_Controller_Router_Route_Static($pageRouteItem[1], 
                    array('controller' => 'dynamic-page', 'action' => 'show', 'id' => $pageRouteItem[0]))
            	);
        }
    }
    
    /**
     * Invoke the front controller's dispatch() method.
     */
    protected function _dispatch()
    {
        if ($this->_frontController == null)
            throw Exception('The front controller has not been initialized.');
        $response = $this->_frontController->dispatch();
        $this->_sendResponse($response);
    }

    protected function _sendResponse(Zend_Controller_Response_Http $response)
    {
        $response->setHeader('Content-Type', 'text/html; charset=UTF-8', true);
        $response->sendResponse();
    }
}
