<?php

/**
 * This class is used to simulate a simple database of pages. It saves this
 * test having to rely on a real db. This could be swapped out easily for 
 * an object which uses a real db.
 */
class DynamicPage_Database
{
    private $_data;
    
    /* Constructor simply populates with data. In a database-driven version, this
        would not be required. */
    public function __construct()
    {
        $this->_data = array(
            /*    ID  URL               TITLE           CONTENT               */
            array( 1, "index/test1",   "First Item",   "<p><b>First</b> item content</p>"),
            array( 2, "index/test2",   "Second Item",  "<p><i>Second</i> item content</p>"),
            array( 3, "index/test3",   "Third Item",   "<p><u>Third</u> item content</p>"),
            array( 4, "index/test4",   "Fourth Item",  "<p>Fourth item content</p>")
            );
    }
    
    /* Returns the info needed for building routes (id and url). I am returning
        arrays, but it could be done with objects instead. That would be better. */
    public function buildRouteData()
    {
        $menuData = array();
        foreach ($this->_data as $item) {
            $menuData []= array($item[0], $item[1]);
        }
        
        return $menuData;
    }
    
    // Returns the data needed for the menu (url with siteroot on the beginning and title)
    public function buildMenu($siteRoot = '')
    {
        $menuData = array();
        foreach ($this->_data as $item) {
            $menuData []= array($siteRoot . '/' . $item[1], $item[2]);
        }
        
        return $menuData;
    }
    
    /* Get content for a given page. In a db-driven version, this would be a simple
        select. */
    public function getPageContent($id)
    {
        foreach ($this->_data as $item) {
            if ($item[0] == $id) {
                return $item[3];
            }
        }
    }
}